@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -122,14 +122,17 @@ static void browser_sort (struct browser_state *state)
   qsort (state->entry, state->entrylen, sizeof (struct folder_file), f);
 }
 
-static int link_is_dir (const char *path)
+static int link_is_dir (const char *folder, const char *path)
 {
   struct stat st;
-
-  if (stat (path, &st) == 0)
+  char fullpath[_POSIX_PATH_MAX];
+  
+  snprintf (fullpath, sizeof (fullpath), "%s/%s", folder, path);
+  
+  if (stat (fullpath, &st) == 0)
     return (S_ISDIR (st.st_mode));
   else
-    return (-1);
+    return 0;
 }
 
 static const char *
@@ -337,6 +340,9 @@ static void init_state (struct browser_state *state, MUTTMENU *menu)
   state->entrymax = 256;
   state->entry = (struct folder_file *) safe_malloc (sizeof (struct folder_file) * state->entrymax);
   memset (state->entry, 0, sizeof (struct folder_file) * state->entrymax);
+#ifdef USE_IMAP
+  state->imap_browse = 0;
+#endif
   if (menu)
     menu->data = state->entry;
 }
@@ -489,7 +495,7 @@ static void init_menu (struct browser_state *state, MUTTMENU *menu, char *title,
 int file_tag (MUTTMENU *menu, int n)
 {
   struct folder_file *ff = &(((struct folder_file *)menu->data)[n]);
-  if (S_ISDIR (ff->mode) || (S_ISLNK (ff->mode) && link_is_dir (ff->name)))
+  if (S_ISDIR (ff->mode) || (S_ISLNK (ff->mode) && link_is_dir (LastDir, ff->name)))
   {
     mutt_error _("Can't attach a directory!");
     return 0;
@@ -596,7 +602,8 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
   if (multiple)
     menu->tag = file_tag;
 
-  menu->help = mutt_compile_help (helpstr, sizeof (helpstr), MENU_FOLDER, FolderHelp);
+  menu->help = mutt_compile_help (helpstr, sizeof (helpstr), MENU_FOLDER,
+    FolderHelp);
 
   init_menu (&state, menu, title, sizeof (title), buffy);
 
@@ -614,7 +621,7 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 
         if (S_ISDIR (state.entry[menu->current].mode) ||
 	    (S_ISLNK (state.entry[menu->current].mode) &&
-	    link_is_dir (state.entry[menu->current].name)) 
+	    link_is_dir (LastDir, state.entry[menu->current].name)) 
 #ifdef USE_IMAP
 	    || state.entry[menu->current].notfolder
 #endif
@@ -793,6 +800,44 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 	}
 	mutt_ungetch (0, OP_CHECK_NEW);
 	break;
+
+      case OP_NEW_MAILBOX:
+	mutt_error (_("Creating mailboxes is not yet supported."));
+	break;
+
+      case OP_DELETE_MAILBOX:
+	if (!mx_is_imap (state.entry[menu->current].name))
+	  mutt_error (_("Delete is only supported for IMAP mailboxes"));
+	else
+        {
+	  char msg[LONG_STRING];
+	  IMAP_MBOX mx;
+	  int nentry = menu->current;
+	  
+	  imap_parse_path (state.entry[nentry].name, &mx);
+	  snprintf (msg, sizeof (msg), _("Really delete mailbox \"%s\"?"),
+            mx.mbox);
+	  if (mutt_yesorno (msg, M_NO) == M_YES)
+          {
+	    if (!imap_delete_mailbox (Context, mx.mbox))
+            {
+	      /* free the mailbox from the browser */
+	      safe_free ((void **) &((state.entry)[nentry].name));
+	      safe_free ((void **) &((state.entry)[nentry].desc));
+	      /* and move all other entries up */
+	      if (nentry+1 < state.entrylen)
+		memmove (state.entry + nentry, state.entry + nentry + 1,
+                  sizeof (struct folder_file) * (state.entrylen - (nentry+1)));
+	      state.entrylen--;
+	      mutt_message _("Mailbox deleted.");
+	      init_menu (&state, menu, title, sizeof (title), buffy);
+	      MAYBE_REDRAW (menu->redraw);
+	    }
+	  }
+	  else
+	    mutt_message _("Mailbox not deleted.");
+        }
+        break;
 #endif
       
       case OP_CHANGE_DIRECTORY:
@@ -801,10 +846,11 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 #ifdef USE_IMAP
 	if (!state.imap_browse)
 #endif
-	{/* add '/' at the end of the directory name */
-	int len=mutt_strlen(LastDir);
-	if (sizeof (buf) > len)
-	  buf[len]='/';
+	{
+	  /* add '/' at the end of the directory name */
+	  int len=mutt_strlen(LastDir);
+	  if (sizeof (buf) > len)
+	    buf[len]='/';
 	}
 
 	if (mutt_get_field (_("Chdir to: "), buf, sizeof (buf), M_FILE) == 0 &&
@@ -1015,7 +1061,7 @@ void _mutt_select_file (char *f, size_t flen, int buffy,
 
         if (S_ISDIR (state.entry[menu->current].mode) ||
 	    (S_ISLNK (state.entry[menu->current].mode) &&
-	    link_is_dir (state.entry[menu->current].name)))
+	    link_is_dir (LastDir, state.entry[menu->current].name)))
 	{
 	  mutt_error _("Can't view a directory");
 	  break;
