@@ -23,7 +23,6 @@
 #include <ctype.h>
 
 #include "mutt.h"
-#include "imap.h"
 #include "imap_private.h"
 #include "message.h"
 #include "mx.h"
@@ -55,7 +54,7 @@ int imap_read_headers (CONTEXT *ctx, int msgbegin, int msgend)
   long bytes = 0;
   int msgno,fetchlast;
   IMAP_HEADER *h, *h0;
-  const char *want_headers = "DATE FROM SUBJECT TO CC MESSAGE-ID REFERENCES CONTENT-TYPE IN-REPLY-TO REPLY-TO";
+  const char *want_headers = "DATE FROM SUBJECT TO CC MESSAGE-ID REFERENCES CONTENT-TYPE IN-REPLY-TO REPLY-TO LINES";
   int using_body_peek = 0;
   fetchlast = 0;
 
@@ -346,6 +345,10 @@ int imap_fetch_message (MESSAGE *msg, CONTEXT *ctx, int msgno)
 	    mutt_set_flag (ctx, h, M_FLAG, h->flagged || newh->flagged);
 	    mutt_set_flag (ctx, h, M_REPLIED, h->replied || newh->replied);
 
+            /* this message is now definitively *not* changed (mutt_set_flag
+             * marks things changed as a side-effect) */
+            h->changed = 0;
+
             mutt_free_list (&(HEADER_DATA(h)->keywords));
             HEADER_DATA(h)->keywords = newh->data->keywords;
             safe_free ((void**) &newh);
@@ -353,14 +356,13 @@ int imap_fetch_message (MESSAGE *msg, CONTEXT *ctx, int msgno)
 	}
       }
       else if (imap_handle_untagged (CTX_DATA, buf) != 0)
-	return (-1);
+	return -1;
     }
   }
-  while (mutt_strncmp (buf, seq, SEQLEN) != 0)
-    ;
+  while (mutt_strncmp (buf, seq, SEQLEN) != 0);
 
   if (!imap_code (buf))
-    return (-1);
+    return -1;
 
   /* Update the header information.  Previously, we only downloaded a
    * portion of the headers, those required for the main display.
@@ -368,6 +370,7 @@ int imap_fetch_message (MESSAGE *msg, CONTEXT *ctx, int msgno)
   rewind (msg->fp);
   mutt_free_envelope (&ctx->hdrs[msgno]->env);
   ctx->hdrs[msgno]->env = mutt_read_rfc822_header (msg->fp, ctx->hdrs[msgno],0, 0);
+  ctx->hdrs[msgno]->lines = 0;
   fgets (buf, sizeof (buf), msg->fp);
   while (!feof (msg->fp))
   {
@@ -393,19 +396,17 @@ int imap_append_message (CONTEXT *ctx, MESSAGE *msg)
 {
   FILE *fp;
   char buf[LONG_STRING];
-  char host[SHORT_STRING];
   char mbox[LONG_STRING];
   char mailbox[LONG_STRING]; 
   char seq[16];
-  char *pc;
-  int port;
   size_t len;
   int c, last;
+  IMAP_MBOX mx;
 
-  if (imap_parse_path (ctx->path, host, sizeof (host), &port, &pc))
+  if (imap_parse_path (ctx->path, &mx))
     return (-1);
 
-  imap_fix_path (CTX_DATA, pc, mailbox, sizeof (mailbox));
+  imap_fix_path (CTX_DATA, mx.mbox, mailbox, sizeof (mailbox));
   
   if ((fp = fopen (msg->path, "r")) == NULL)
   {
@@ -515,30 +516,28 @@ int imap_append_message (CONTEXT *ctx, MESSAGE *msg)
  *       1: non-fatal error - try fetch/append */
 int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
 {
-  char buf[LONG_STRING];
+  char buf[HUGE_STRING];
   char cmd[LONG_STRING];
   char mbox[LONG_STRING];
-  char host[SHORT_STRING];
-  int port;
-  char* pc;
   int rc;
   int n;
+  IMAP_MBOX mx;
 
-  if (imap_parse_path (dest, host, sizeof (host), &port, &pc))
+  if (imap_parse_path (dest, &mx))
   {
     dprint (1, (debugfile, "imap_copy_message: bad destination %s\n", dest));
     return -1;
   }
 
   /* check that the save-to folder is on the same server */
-  if (mutt_socket_select_connection (host, port, 0) != CTX_DATA->conn)
+  if (mutt_socket_select_connection (&mx, 0) != CTX_DATA->conn)
   {
     dprint (3, (debugfile, "imap_copy_message: %s not same server as %s\n",
       dest, ctx->path));
     return 1;
   }
 
-  imap_fix_path (CTX_DATA, pc, cmd, sizeof (cmd));
+  imap_fix_path (CTX_DATA, mx.mbox, cmd, sizeof (cmd));
 
   /* Null HEADER* means copy tagged messages */
   if (!h)
@@ -563,13 +562,22 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
   rc = imap_exec (buf, sizeof (buf), CTX_DATA, cmd, IMAP_OK_FAIL);
   if (rc == -2)
   {
-    /* command failed because folder doesn't exist */
+    /* bail out if command failed for reasons other than nonexistent target */
+    if (strncmp (imap_get_qualifier (buf), "[TRYCREATE]", 11))
+    {
+      imap_error ("imap_copy_messages", buf);
+      return -1;
+    }
+    dprint (2, (debugfile, "imap_copy_messages: server suggests TRYCREATE\n"));
     if (option (OPTCONFIRMCREATE))
     {
       snprintf (buf, sizeof (buf), _("Create %s?"), mbox);
       if (mutt_yesorno (buf, 1) < 1)
+      {
+        mutt_clear_error ();
 	return -1;
-      if (imap_create_mailbox (CTX_DATA, mbox) < 0)
+      }
+      if (imap_create_mailbox (ctx, mbox) < 0)
 	return -1;
     }
     /* try again */
@@ -585,7 +593,6 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
   if (delete)
   {
     if (!h)
-    {
       for (n = 0; n < ctx->msgcount; n++)
       {
         if (ctx->hdrs[n]->tagged)
@@ -595,7 +602,6 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
             mutt_set_flag (ctx, ctx->hdrs[n], M_TAG, 0);
         }
       }
-    }
     else
     {
       mutt_set_flag (ctx, h, M_DELETE, 1);
