@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999   Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1999-2000 Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -41,17 +41,18 @@ static const char *ReachingUs = N_("\
 To contact the developers, please mail to <mutt-dev@mutt.org>.\n");
 
 static const char *Notice = N_("\
-Copyright (C) 1996-9 Michael R. Elkins and others.\n\
+Copyright (C) 1996-2000 Michael R. Elkins and others.\n\
 Mutt comes with ABSOLUTELY NO WARRANTY; for details type `mutt -vv'.\n\
 Mutt is free software, and you are welcome to redistribute it\n\
 under certain conditions; type `mutt -vv' for details.\n");
 
 static const char *Copyright = N_("\
-Copyright (C) 1996-9 Michael R. Elkins <me@cs.hmc.edu>\n\
-Copyright (C) 1996-9 Brandon Long <blong@fiction.net>\n\
-Copyright (C) 1997-9 Thomas Roessler <roessler@guug.de>\n\
-Copyright (C) 1998-9 Werner Koch <wk@isil.d.shuttle.de>\n\
-Copyright (C) 1999   Brendan Cully <brendan@kublai.com>\n\
+Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>\n\
+Copyright (C) 1996-2000 Brandon Long <blong@fiction.net>\n\
+Copyright (C) 1997-2000 Thomas Roessler <roessler@guug.de>\n\
+Copyright (C) 1998-2000 Werner Koch <wk@isil.d.shuttle.de>\n\
+Copyright (C) 1999-2000 Brendan Cully <brendan@kublai.com>\n\
+Copyright (C) 1999-2000 Tommi Komulainen <Tommi.Komulainen@iki.fi>\n\
 \n\
 Lots of others not mentioned here contributed lots of code,\n\
 fixes, and suggestions.\n\
@@ -73,7 +74,7 @@ fixes, and suggestions.\n\
 #ifdef _PGPPATH
 
 const char* ShaCopyright = N_("\n\
-SHA1 implementation Copyright (C) 1995-7 Eric A. Young <eay@cryptsoft.com>\n\
+SHA1 implementation Copyright (C) 1995-1997 Eric A. Young <eay@cryptsoft.com>\n\
 \n\
     Redistribution and use in source and binary forms, with or without\n\
     modification, are permitted under certain conditions.\n\
@@ -203,6 +204,12 @@ static void show_version (void)
 	"-USE_GSS  "
 #endif
 
+#ifdef USE_SSL
+	"+USE_SSL  "
+#else
+	"-USE_SSL  "
+#endif
+
 #ifdef USE_POP
 	"+USE_POP  "
 #else
