@@ -21,7 +21,7 @@
 #include "mailbox.h"
 #include "mime.h"
 #include "rfc2047.h"
-
+#include "rfc2231.h"
 
 
 #ifdef _PGPPATH
@@ -138,12 +138,14 @@ static PARAMETER *parse_parameters (const char *s)
   const char *p;
   size_t i;
 
+  dprint (2, (debugfile, "parse_parameters: `%s'\n", s));
+  
   while (*s)
   {
     if ((p = strpbrk (s, "=;")) == NULL)
     {
       dprint(1, (debugfile, "parse_parameters: malformed parameter: %s\n", s));
-      return (head); /* just bail out now */
+      goto bail;
     }
 
     /* if we hit a ; now the parameter has no value, just skip it */
@@ -192,6 +194,8 @@ static PARAMETER *parse_parameters (const char *s)
 
       new->value = safe_strdup (buffer);
 
+      dprint (2, (debugfile, "parse_parameter: `%s' = `%s'\n", new->attribute, new->value));
+      
       /* Add this parameter to the list */
       if (head)
       {
@@ -221,6 +225,9 @@ static PARAMETER *parse_parameters (const char *s)
     while (*s == ';'); /* skip empty parameters */
   }    
 
+  bail:
+
+  rfc2231_decode_parameters (&head);
   return (head);
 }
 
@@ -310,6 +317,13 @@ void mutt_parse_content_type (char *s, BODY *ct)
       ct->subtype = safe_strdup ("x-unknown");
   }
 
+  /* Default character set for text types. */
+  if (ct->type == TYPETEXT)
+  {
+    if (!(pc = mutt_get_parameter ("charset", ct->parameter)))
+      mutt_set_parameter ("charset", "us-ascii", &ct->parameter);
+  }
+
 }
 
 static void parse_content_disposition (char *s, BODY *ct)
@@ -463,7 +477,7 @@ BODY *mutt_parse_messageRFC822 (FILE *fp, BODY *parent)
 
   parent->hdr = mutt_new_header ();
   parent->hdr->offset = ftell (fp);
-  parent->hdr->env = mutt_read_rfc822_header (fp, parent->hdr, 0);
+  parent->hdr->env = mutt_read_rfc822_header (fp, parent->hdr, 0, 0);
   msg = parent->hdr->content;
 
   /* ignore the length given in the content-length since it could be wrong
@@ -511,11 +525,7 @@ BODY *mutt_parse_multipart (FILE *fp, const char *boundary, long end_off, int di
   {
     len = mutt_strlen (buffer);
 
-    /* take note of the line ending.  I'm assuming that either all endings
-     * will use <CR><LF> or none will.
-     */
-    if (len > 1 && buffer[len - 2] == '\r')
-      crlf = 1;
+    crlf =  (len > 1 && buffer[len - 2] == '\r') ? 1 : 0;
 
     if (buffer[0] == '-' && buffer[1] == '-' &&
 	mutt_strncmp (buffer + 2, boundary, blen) == 0)
@@ -851,11 +861,16 @@ void mutt_parse_mime_message (CONTEXT *ctx, HEADER *cur)
  *
  * hdr		header structure of current message (optional).
  * 
- * user_hdrs	If set, store user headers.  Used for edit-message and 
+ * user_hdrs	If set, store user headers.  Used for recall-message and
  * 		postpone modes.
  * 
+ * weed		If this parameter is set and the user has activated the
+ * 		$weed option, honor the header weed list for user headers.
+ * 	        Used for recall-message.
+ * 
  */
-ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
+ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs,
+				   short weed)
 {
   ENVELOPE *e = mutt_new_envelope();
   LIST *last = NULL;
@@ -963,7 +978,10 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
 	  else if (mutt_strcasecmp (line+8, "length") == 0)
 	  {
 	    if (hdr)
-	      hdr->content->length = atoi (p);
+	    {
+	      if ((hdr->content->length = atoi (p)) < 0)
+		hdr->content->length = -1;
+	    }
 	    matched = 1;
 	  }
 	  else if (mutt_strcasecmp (line+8, "description") == 0)
@@ -1176,6 +1194,13 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
      /* Keep track of the user-defined headers */
     if (!matched && user_hdrs)
     {
+      /* restore the original line */
+      line[strlen (line)] = ':';
+
+      if (weed && option (OPTWEED) && mutt_matches_ignore (line, Ignore)
+	  && !mutt_matches_ignore (line, UnIgnore))
+	continue;
+
       if (last)
       {
 	last->next = mutt_new_list ();
@@ -1183,7 +1208,6 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
       }
       else
 	last = e->userhdrs = mutt_new_list ();
-      line[strlen (line)] = ':';
       last->data = safe_strdup (line);
     }
 
