@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1996-1998 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999 Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1999-2000Thomas Roessler <roessler@guug.de>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -737,6 +737,12 @@ mutt_attach_display_loop (MUTTMENU *menu, int op, FILE *fp, HEADER *hdr,
 	else
 	  op = OP_NULL;
 	break;
+      case OP_EDIT_TYPE:
+	/* when we edit the content-type, we should redisplay the attachment
+	   immediately */
+	mutt_edit_content_type (hdr, idx[menu->current]->content);
+	op = OP_VIEW_ATTACH;
+	break;
       default:
 	op = OP_NULL;
     }
@@ -993,6 +999,11 @@ void mutt_view_attachments (HEADER *hdr)
 	menu->redraw = REDRAW_FULL;
 	break;
 
+      case OP_EDIT_TYPE:
+	mutt_edit_content_type (hdr, idx[menu->current]->content);
+	menu->redraw = REDRAW_CURRENT;
+	break;
+
       case OP_EXIT:
 	mx_close_message (&msg);
 	hdr->attach_del = 0;
@@ -1010,14 +1021,6 @@ void mutt_view_attachments (HEADER *hdr)
 
 
 
-
-
-
-
-
-
-
-
 #ifdef _PGPPATH
 	if (pgp)
 	{
