@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -26,8 +26,6 @@
 
 typedef void encode_t (char *, size_t, const unsigned char *, const char *);
 
-extern char MimeSpecials[];
-extern char B64Chars[];
 
 static void q_encode_string (char *d, 
 			     size_t dlen, 
@@ -46,7 +44,7 @@ static void q_encode_string (char *d,
   if(hibit)
   {
     snprintf (charset, sizeof (charset), "=?%s?Q?",
-	      mutt_strcasecmp ("us-ascii", Charset) == 0 ? "unknown-8bit" : NONULL(Charset));
+	      mutt_strcasecmp ("us-ascii", send_charset) == 0 ? "unknown-8bit" : NONULL(send_charset));
   }
   else
     strfcpy(charset, "=?us-ascii?Q?", sizeof(charset));
