@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -898,8 +898,8 @@ static int send_message (HEADER *msg)
     return mix_send_message (msg->chain, tempfile);
 #endif
 
-  i = mutt_invoke_sendmail (msg->env->to, msg->env->cc, msg->env->bcc,
-		       tempfile, (msg->content->encoding == ENC8BIT));
+  i = mutt_invoke_sendmail (msg->env->from, msg->env->to, msg->env->cc, 
+			    msg->env->bcc, tempfile, (msg->content->encoding == ENC8BIT));
   return (i);
 }
 
@@ -1236,6 +1236,7 @@ ci_send_message (int flags,		/* send mode */
     }
   }
 
+  
   mutt_update_encoding (msg->content);
 
   if (! (flags & (SENDMAILX | SENDBATCH)))
@@ -1342,6 +1343,22 @@ main_loop:
   /* save a copy of the message, if necessary. */
 
   mutt_expand_path (fcc, sizeof (fcc));
+
+  
+  /* Don't save a copy when we are in batch-mode, and the FCC
+   * folder is on an IMAP server: This would involve possibly lots
+   * of user interaction, which is not available in batch mode. 
+   * 
+   * Note: A patch to fix the problems with the use of IMAP servers
+   * from non-curses mode is available from Brendan Cully.  However, 
+   * I'd like to think a bit more about this before including it.
+   */
+
+#ifdef USE_IMAP
+  if ((flags & SENDBATCH) && fcc[0] && mx_is_imap (fcc))
+    fcc[0] = '\0';
+#endif
+
   if (*fcc && mutt_strcmp ("/dev/null", fcc) != 0)
   {
     BODY *tmpbody = msg->content;
@@ -1350,6 +1367,11 @@ main_loop:
     BODY *save_parts = NULL;
 #endif /* _PGPPATH */
 
+#ifdef _PGPPATH
+    if (msg->pgp && option (OPTFCCCLEAR))
+      msg->content = clear_content;
+#endif
+
     /* check to see if the user wants copies of all attachments */
     if (!option (OPTFCCATTACH) && msg->content->type == TYPEMULTIPART)
     {
